@@ -355,7 +355,8 @@ mod imp {
 
 glib::wrapper! {
     pub struct ResProcesses(ObjectSubclass<imp::ResProcesses>)
-        @extends gtk::Widget, adw::Bin;
+        @extends gtk::Widget, adw::Bin,
+        @implements gtk::Buildable, gtk::ConstraintTarget, gtk::Accessible;
 }
 
 impl Default for ResProcesses {
@@ -464,6 +465,7 @@ impl ResProcesses {
         columns.push(self.add_priority_column(&column_view));
         columns.push(self.add_swap_column(&column_view));
         columns.push(self.add_combined_memory_column(&column_view));
+        columns.push(self.add_commandline_column(&column_view));
 
         let store = gio::ListStore::new::<ProcessEntry>();
 
@@ -664,7 +666,7 @@ impl ResProcesses {
             }
         ));
 
-        dialog.present(Some(&MainWindow::default()));
+        adw::prelude::AdwDialogExt::present(&dialog, Some(&MainWindow::default()));
 
         *imp.open_options_dialog.borrow_mut() = Some((process.pid(), dialog));
     }
@@ -690,7 +692,7 @@ impl ResProcesses {
             }
         ));
 
-        dialog.present(Some(&MainWindow::default()));
+        AdwDialogExt::present(&dialog, Some(&MainWindow::default()));
 
         *imp.open_info_dialog.borrow_mut() = Some((process.pid(), dialog));
     }
@@ -769,13 +771,13 @@ impl ResProcesses {
                 // filter out processes that have existed before but don't anymore
                 if let Some((dialog_pid, dialog)) = &*info_dialog_opt {
                     if *dialog_pid == item_pid {
-                        dialog.close();
+                        AdwDialogExt::close(dialog);
                         *info_dialog_opt = None;
                     }
                 }
                 if let Some((dialog_pid, dialog)) = &*options_dialog_opt {
                     if *dialog_pid == item_pid {
-                        dialog.close();
+                        AdwDialogExt::close(dialog);
                         *options_dialog_opt = None;
                     }
                 }
@@ -1087,6 +1089,7 @@ impl ResProcesses {
 
                 let row = gtk::Inscription::new(None);
                 row.set_min_chars(9);
+                row.set_xalign(1.0);
 
                 item.set_child(Some(&row));
 
@@ -1145,6 +1148,7 @@ impl ResProcesses {
 
                 let row = gtk::Inscription::new(None);
                 row.set_min_chars(7);
+                row.set_xalign(1.0);
 
                 item.set_child(Some(&row));
 
@@ -1210,6 +1214,7 @@ impl ResProcesses {
 
                 let row = gtk::Inscription::new(None);
                 row.set_min_chars(11);
+                row.set_xalign(1.0);
 
                 item.set_child(Some(&row));
 
@@ -1276,6 +1281,7 @@ impl ResProcesses {
 
                 let row = gtk::Inscription::new(None);
                 row.set_min_chars(9);
+                row.set_xalign(1.0);
 
                 item.set_child(Some(&row));
 
@@ -1342,6 +1348,7 @@ impl ResProcesses {
 
                 let row = gtk::Inscription::new(None);
                 row.set_min_chars(11);
+                row.set_xalign(1.0);
 
                 item.set_child(Some(&row));
 
@@ -1408,6 +1415,7 @@ impl ResProcesses {
 
                 let row = gtk::Inscription::new(None);
                 row.set_min_chars(9);
+                row.set_xalign(1.0);
 
                 item.set_child(Some(&row));
 
@@ -1471,6 +1479,7 @@ impl ResProcesses {
 
                 let row = gtk::Inscription::new(None);
                 row.set_min_chars(7);
+                row.set_xalign(1.0);
 
                 item.set_child(Some(&row));
 
@@ -1531,6 +1540,7 @@ impl ResProcesses {
 
                 let row = gtk::Inscription::new(None);
                 row.set_min_chars(7);
+                row.set_xalign(1.0);
 
                 item.set_child(Some(&row));
 
@@ -1591,6 +1601,7 @@ impl ResProcesses {
 
                 let row = gtk::Inscription::new(None);
                 row.set_min_chars(7);
+                row.set_xalign(1.0);
 
                 item.set_child(Some(&row));
 
@@ -1651,6 +1662,7 @@ impl ResProcesses {
 
                 let row = gtk::Inscription::new(None);
                 row.set_min_chars(9);
+                row.set_xalign(1.0);
 
                 item.set_child(Some(&row));
                 item.property_expression("item")
@@ -1952,6 +1964,7 @@ impl ResProcesses {
 
                 let row = gtk::Inscription::new(None);
                 row.set_min_chars(9);
+                row.set_xalign(1.0);
 
                 item.set_child(Some(&row));
 
@@ -2012,6 +2025,7 @@ impl ResProcesses {
 
                 let row = gtk::Inscription::new(None);
                 row.set_min_chars(9);
+                row.set_xalign(1.0);
 
                 item.set_child(Some(&row));
 
@@ -2053,6 +2067,63 @@ impl ResProcesses {
 
         combined_memory_col
     }
+
+    fn add_commandline_column(&self, column_view: &ColumnView) -> ColumnViewColumn {
+        let commandline_col_factory = gtk::SignalListItemFactory::new();
+
+        let commandline_col = gtk::ColumnViewColumn::new(
+            Some(&i18n("Commandline")),
+            Some(commandline_col_factory.clone()),
+        );
+
+        commandline_col.set_resizable(true);
+
+        commandline_col_factory.connect_setup(clone!(
+            #[weak(rename_to = this)]
+            self,
+            move |_factory, item| {
+                let item = item.downcast_ref::<gtk::ListItem>().unwrap();
+
+                let row = gtk::Inscription::new(None);
+                row.set_min_chars(32);
+
+                item.set_child(Some(&row));
+
+                item.property_expression("item")
+                    .chain_property::<ProcessEntry>("commandline")
+                    .bind(&row, "text", Widget::NONE);
+
+                this.add_gestures(item);
+            }
+        ));
+
+        commandline_col_factory.connect_teardown(move |_factory, item| {
+            let item = item.downcast_ref::<gtk::ListItem>().unwrap();
+            item.set_child(None::<&gtk::Inscription>);
+        });
+
+        let commandline_col_sorter = StringSorter::builder()
+            .ignore_case(true)
+            .expression(gtk::PropertyExpression::new(
+                ProcessEntry::static_type(),
+                None::<&gtk::Expression>,
+                "commandline",
+            ))
+            .build();
+
+        commandline_col.set_sorter(Some(&commandline_col_sorter));
+        commandline_col.set_visible(SETTINGS.processes_show_commandline());
+
+        column_view.append_column(&commandline_col);
+
+        SETTINGS.connect_processes_show_commandline(clone!(
+            #[weak]
+            commandline_col,
+            move |visible| commandline_col.set_visible(visible)
+        ));
+
+        commandline_col
+    }
 }
 
 fn get_action_name(action: ProcessAction, name: &str) -> String {
