@@ -63,7 +63,7 @@ mod imp {
     use async_channel::{Receiver, Sender, unbounded};
     use gtk::CompositeTemplate;
     use log::debug;
-    use process_data::{GpuIdentifier, pci_slot::PciSlot};
+    use process_data::{gpu_usage::GpuIdentifier, pci_slot::PciSlot};
 
     #[derive(Debug, CompositeTemplate)]
     #[template(resource = "/net/nokyan/Resources/ui/window.ui")]
@@ -206,7 +206,8 @@ mod imp {
 glib::wrapper! {
     pub struct MainWindow(ObjectSubclass<imp::MainWindow>)
         @extends gtk::Widget, gtk::Window, gtk::ApplicationWindow, adw::ApplicationWindow,
-        @implements gio::ActionMap, gio::ActionGroup, gtk::Root;
+        @implements gio::ActionMap, gio::ActionGroup, gtk::Root, gtk::Buildable, gtk::ConstraintTarget, gtk::Native,
+        gtk::ShortcutManager, gtk::Accessible;
 }
 
 struct RefreshData {
@@ -271,7 +272,7 @@ impl MainWindow {
             *imp.apps_context.borrow_mut() = AppsContext::new(
                 gpus.iter()
                     .filter(|gpu| gpu.combined_media_engine().unwrap_or_default())
-                    .map(Gpu::gpu_identifier)
+                    .map(|gpu| gpu.gpu_identifier())
                     .collect(),
             );
             imp.apps.init(imp.sender.clone());
@@ -357,7 +358,7 @@ impl MainWindow {
                 if key == gdk::Key::Control_L {
                     debug!("Ctrl is being held, halting apps and processes updates");
                     this.imp().pause_updates.set(true);
-                };
+                }
                 glib::Propagation::Proceed
             }
         ));
@@ -366,12 +367,25 @@ impl MainWindow {
             imp,
             move |_, key, _, _| {
                 if key == gdk::Key::Control_L {
-                    debug!("Ctrl has been released, continuing apps and processes updates");
+                    debug!("Ctrl has been released, resuming apps and processes updates");
                     imp.pause_updates.set(false);
                 };
             }
         ));
         self.add_controller(event_controller);
+
+        self.connect_suspended_notify(clone!(
+            #[weak]
+            imp,
+            move |window| {
+                imp.pause_updates.set(window.is_suspended());
+                if window.is_suspended() {
+                    debug!("Resources has been suspended, halting graphical updates");
+                } else {
+                    debug!("Resources is not suspended anymore, resuming graphical updates");
+                }
+            }
+        ));
     }
 
     fn get_selected_page(&self) -> Option<Widget> {
@@ -549,6 +563,7 @@ impl MainWindow {
             NetworkInterface::get_sysfs_paths().unwrap_or_default()
         };
         let mut network_data = Vec::with_capacity(network_paths.len());
+
         for path in &network_paths {
             network_data.push(NetworkData::new(path));
         }
@@ -676,6 +691,13 @@ impl MainWindow {
                     "DRM decode: {drm_decode_fraction} · Process-based decode: {processes_decode_fraction} · Using {highest_decode_fraction}"
                 );
                 gpu_data.decode_fraction = Some(highest_decode_fraction);
+
+                if gpu_data.used_vram.is_none() {
+                    gpu_data.used_vram = Some(apps_context.vram_usage(gpu_data.gpu_identifier));
+                    trace!(
+                        "Couldn't read sysfs VRAM usage, falling back to summing up per-process usage…"
+                    )
+                }
             }
 
             page.refresh_page(&gpu_data);
@@ -861,7 +883,7 @@ impl MainWindow {
 
     /// Wrapper to remove page, and check if removed page was visible with global default behavior
     fn remove_page(&self, page: &ToolbarView) {
-        trace!("Removing page {:?}…", page);
+        trace!("Removing page {page:?}…");
 
         let imp = self.imp();
 
@@ -891,10 +913,7 @@ impl MainWindow {
             .max()
             .unwrap_or_default();
 
-        let old_page_paths: Vec<PathBuf> = drive_pages
-            .iter()
-            .map(|(path, _)| path.to_owned())
-            .collect();
+        let old_page_paths: Vec<PathBuf> = drive_pages.keys().map(ToOwned::to_owned).collect();
 
         // Filter hidden drives
         for data in drive_data {
@@ -966,10 +985,7 @@ impl MainWindow {
             .max()
             .unwrap_or_default();
 
-        let old_page_paths: Vec<PathBuf> = network_pages
-            .iter()
-            .map(|(path, _)| path.to_owned())
-            .collect();
+        let old_page_paths: Vec<PathBuf> = network_pages.keys().map(ToOwned::to_owned).collect();
 
         // Filter hidden networks
         for data in network_data {
@@ -1161,7 +1177,7 @@ impl MainWindow {
                     toast_overlay.add_toast(Toast::new(&toast_message));
                 }
             }
-        };
+        }
     }
 
     fn save_window_size(&self) -> Result<(), glib::BoolError> {
